import {
	scaleBand,
  scaleLinear,
  axisBottom,
  axisLeft,
  max,
} from 'd3';

export const attributeHistogram = (selection, props) => {
	const {
  	margin,
    height,
    width,
    data,
    index,
  } = props;
  
  const x = scaleBand()
    .domain(data.map(d => d.name))
    .range([margin.left, width - margin.right])
    .padding(0.1);
  
  const y = scaleLinear()
    .domain([0, max(data, d => d.value)]).nice()
    .range([height - margin.bottom, margin.top]);
  
  const xAxis = g => g
    .attr('transform', `translate(0,${height - margin.bottom})`)
    .call(axisBottom(x).tickSizeOuter(0));
  
  const yAxis = g => g
    .attr('transform', `translate(${margin.left},0)`)
    .call(axisLeft(y))
    .call(g => g.select('.domain').remove());
  
  let div = d3.select("body").append("div")	
      .attr("class", "tooltip")				
      .style("opacity", 0);
  
  const bars = selection
  	.selectAll(`.${index}`)
  	.data(data);
  const barsEnter = bars
    .enter().append('rect')
      .attr('class', `${index}`)
      .attr('fill', 'steelblue')
      .attr('x', d => x(d.name))
      .attr('y', d => y(d.value))
      .attr('height', d => y(0) - y(d.value))
      .attr('width', x.bandwidth())
      .on('mouseover', function(d) {		
            div.transition()		
                .duration(100)		
                .style("opacity", .9);		
            div.html(d.name)	
                .style("left", (d3.event.pageX) + "px")		
                .style("top", (d3.event.pageY - 28) + "px");	
          })					
      .on('mouseout', function(d) {		
          div.transition()		
              .duration(500)		
              .style("opacity", 0);	
      	});
  
  // selection.append('g')
  //     .call(xAxis);
  
  selection.append('g')
      .call(yAxis);
  
  selection.append('text')
    .text(index)
    .attr('x', 100)
    .attr('y', 20)
}





