import { hierarchy } from 'd3';
export const eventSequences = (selection, props) => {
  const {
    data,
    regex,
    margin,
    spacing,
    length,
    selectedSequence,
    handleSequence,
    handleEvent,
  } = props;
  
  selection.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  
  // Selection & Enter for Sequences
  const sequences = selection
    .selectAll('.sequences')
    .data(data, (d,i) => [d[0].data.id, regex]);
  
  const sequencesEnter = sequences
    .enter().append('g')
      .attr('class', 'sequences')
      .attr('transform', (d,i) => 
            `translate(0, ${(length + spacing.bottom) * i})`)
      .on('mouseover', (d,i) => handleSequence(d,i));
  
  sequencesEnter.append('text')
    .attr('x', (d) => (length + spacing.bottom) * (d.length-1))
    .attr('y', 0)
    .attr('dy', '0.85em')
    .text((d) => d[0].data.data.count);
  
  sequences.exit().remove();
  
  
  // Selection & Enter for Events
  const events = sequencesEnter.selectAll('rect').data((d) => d.slice(1));
  const eventsEnter = events
    .enter().append('rect')
      .attr('width', length)
      .attr('height', length)
      .attr('stroke', 'none')
      .attr('stroke-width', '0.3px')
      .attr('x', (d, i) => (spacing.right + length) * i)
  		.attr('fill', (d) => {
        if(check(regex, d.data.data, handleEvent)) return '#42f462';
        return '#606060';
      });
  
  
  // Render Selected Sequence
  const crumbs = selection
  	.selectAll('.breadcrumbs')
  	.data(selectedSequence || [], d => String(d.id));
  crumbs
    .enter().append('text')
      .text(d => (d.data.data.N) ? d.data.data.N : '-')
      .attr('class', 'breadcrumbs')
      .attr('font-size', '20px')
      .attr('fill', 'gray')
      .attr('x', 300)
      .attr('y', (d, i) => 22 * i);
  crumbs.exit().remove();
}


function check(regex, data, updateMeta) {
  const properties = ['N', 'CN', 'CT'];
  for(let prop_i in properties) 
  {
    const prop = properties[prop_i];
    if(data.hasOwnProperty(prop) && regex) {
      if(regex.exec(data[prop])) {
        updateMeta(true);
        return true;
      }
    }
  }
  
  updateMeta(false);
  return false;
}

